/* SerializablePropertyIntTest.c generated by valac 0.44.3, the Vala compiler
 * generated from SerializablePropertyIntTest.vala, do not modify */

/* -*- Mode: vala; indent-tabs-mode: nil; tab-width: 2 -*- */

#include <glib-object.h>
#include <glib.h>
#include <gxml/gxml.h>
#include <stdlib.h>
#include <string.h>

#define TYPE_GXML_TEST (gxml_test_get_type ())
#define GXML_TEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GXML_TEST, GXmlTest))
#define GXML_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_GXML_TEST, GXmlTestClass))
#define IS_GXML_TEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GXML_TEST))
#define IS_GXML_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_GXML_TEST))
#define GXML_TEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_GXML_TEST, GXmlTestClass))

typedef struct _GXmlTest GXmlTest;
typedef struct _GXmlTestClass GXmlTestClass;
typedef struct _GXmlTestPrivate GXmlTestPrivate;

#define TYPE_SERIALIZABLE_PROPERTY_INT_TEST (serializable_property_int_test_get_type ())
#define SERIALIZABLE_PROPERTY_INT_TEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SERIALIZABLE_PROPERTY_INT_TEST, SerializablePropertyIntTest))
#define SERIALIZABLE_PROPERTY_INT_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SERIALIZABLE_PROPERTY_INT_TEST, SerializablePropertyIntTestClass))
#define IS_SERIALIZABLE_PROPERTY_INT_TEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SERIALIZABLE_PROPERTY_INT_TEST))
#define IS_SERIALIZABLE_PROPERTY_INT_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SERIALIZABLE_PROPERTY_INT_TEST))
#define SERIALIZABLE_PROPERTY_INT_TEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SERIALIZABLE_PROPERTY_INT_TEST, SerializablePropertyIntTestClass))

typedef struct _SerializablePropertyIntTest SerializablePropertyIntTest;
typedef struct _SerializablePropertyIntTestClass SerializablePropertyIntTestClass;
typedef struct _SerializablePropertyIntTestPrivate SerializablePropertyIntTestPrivate;

#define SERIALIZABLE_PROPERTY_INT_TEST_TYPE_INT_NODE (serializable_property_int_test_int_node_get_type ())
#define SERIALIZABLE_PROPERTY_INT_TEST_INT_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERIALIZABLE_PROPERTY_INT_TEST_TYPE_INT_NODE, SerializablePropertyIntTestIntNode))
#define SERIALIZABLE_PROPERTY_INT_TEST_INT_NODE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERIALIZABLE_PROPERTY_INT_TEST_TYPE_INT_NODE, SerializablePropertyIntTestIntNodeClass))
#define SERIALIZABLE_PROPERTY_INT_TEST_IS_INT_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERIALIZABLE_PROPERTY_INT_TEST_TYPE_INT_NODE))
#define SERIALIZABLE_PROPERTY_INT_TEST_IS_INT_NODE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERIALIZABLE_PROPERTY_INT_TEST_TYPE_INT_NODE))
#define SERIALIZABLE_PROPERTY_INT_TEST_INT_NODE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERIALIZABLE_PROPERTY_INT_TEST_TYPE_INT_NODE, SerializablePropertyIntTestIntNodeClass))

typedef struct _SerializablePropertyIntTestIntNode SerializablePropertyIntTestIntNode;
typedef struct _SerializablePropertyIntTestIntNodeClass SerializablePropertyIntTestIntNodeClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _SerializablePropertyIntTestIntNodePrivate SerializablePropertyIntTestIntNodePrivate;
enum  {
	SERIALIZABLE_PROPERTY_INT_TEST_INT_NODE_0_PROPERTY,
	SERIALIZABLE_PROPERTY_INT_TEST_INT_NODE_INTEGER_PROPERTY,
	SERIALIZABLE_PROPERTY_INT_TEST_INT_NODE_NAME_PROPERTY,
	SERIALIZABLE_PROPERTY_INT_TEST_INT_NODE_NUM_PROPERTIES
};
static GParamSpec* serializable_property_int_test_int_node_properties[SERIALIZABLE_PROPERTY_INT_TEST_INT_NODE_NUM_PROPERTIES];
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _GXmlTest {
	GTypeInstance parent_instance;
	volatile int ref_count;
	GXmlTestPrivate * priv;
};

struct _GXmlTestClass {
	GTypeClass parent_class;
	void (*finalize) (GXmlTest *self);
};

struct _SerializablePropertyIntTest {
	GXmlTest parent_instance;
	SerializablePropertyIntTestPrivate * priv;
};

struct _SerializablePropertyIntTestClass {
	GXmlTestClass parent_class;
};

struct _SerializablePropertyIntTestIntNode {
	GXmlSerializableObjectModel parent_instance;
	SerializablePropertyIntTestIntNodePrivate * priv;
};

struct _SerializablePropertyIntTestIntNodeClass {
	GXmlSerializableObjectModelClass parent_class;
};

struct _SerializablePropertyIntTestIntNodePrivate {
	GXmlSerializableInt* _integer;
	gchar* _name;
};

static gpointer serializable_property_int_test_parent_class = NULL;
static gint SerializablePropertyIntTestIntNode_private_offset;
static gpointer serializable_property_int_test_int_node_parent_class = NULL;

gpointer gxml_test_ref (gpointer instance);
void gxml_test_unref (gpointer instance);
GParamSpec* param_spec_gxml_test (const gchar* name,
                                  const gchar* nick,
                                  const gchar* blurb,
                                  GType object_type,
                                  GParamFlags flags);
void value_set_gxml_test (GValue* value,
                          gpointer v_object);
void value_take_gxml_test (GValue* value,
                           gpointer v_object);
gpointer value_get_gxml_test (const GValue* value);
GType gxml_test_get_type (void) G_GNUC_CONST;
GType serializable_property_int_test_get_type (void) G_GNUC_CONST;
void serializable_property_int_test_add_tests (void);
static void __lambda252_ (void);
GType serializable_property_int_test_int_node_get_type (void) G_GNUC_CONST;
SerializablePropertyIntTestIntNode* serializable_property_int_test_int_node_new (void);
SerializablePropertyIntTestIntNode* serializable_property_int_test_int_node_construct (GType object_type);
static void ___lambda252__gtest_func (void);
static void __lambda253_ (void);
void serializable_property_int_test_int_node_set_integer (SerializablePropertyIntTestIntNode* self,
                                                          GXmlSerializableInt* value);
GXmlSerializableInt* serializable_property_int_test_int_node_get_integer (SerializablePropertyIntTestIntNode* self);
static void ___lambda253__gtest_func (void);
static void __lambda254_ (void);
static void ___lambda254__gtest_func (void);
static void __lambda255_ (void);
static void ___lambda255__gtest_func (void);
SerializablePropertyIntTest* serializable_property_int_test_new (void);
SerializablePropertyIntTest* serializable_property_int_test_construct (GType object_type);
GXmlTest* gxml_test_new (void);
GXmlTest* gxml_test_construct (GType object_type);
static gchar* serializable_property_int_test_int_node_real_node_name (GXmlSerializableObjectModel* base);
static gchar* serializable_property_int_test_int_node_real_to_string (GXmlSerializableObjectModel* base);
static gboolean serializable_property_int_test_int_node_real_property_use_nick (GXmlSerializableObjectModel* base);
const gchar* serializable_property_int_test_int_node_get_name (SerializablePropertyIntTestIntNode* self);
void serializable_property_int_test_int_node_set_name (SerializablePropertyIntTestIntNode* self,
                                                       const gchar* value);
static void serializable_property_int_test_int_node_finalize (GObject * obj);
static void _vala_serializable_property_int_test_int_node_get_property (GObject * object,
                                                                 guint property_id,
                                                                 GValue * value,
                                                                 GParamSpec * pspec);
static void _vala_serializable_property_int_test_int_node_set_property (GObject * object,
                                                                 guint property_id,
                                                                 const GValue * value,
                                                                 GParamSpec * pspec);

static const gchar*
string_to_string (const gchar* self)
{
	const gchar* result = NULL;
#line 1516 "glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1517 "glib-2.0.vapi"
	result = self;
#line 1517 "glib-2.0.vapi"
	return result;
#line 157 "SerializablePropertyIntTest.c"
}

static void
__lambda252_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		SerializablePropertyIntTestIntNode* bn = NULL;
		SerializablePropertyIntTestIntNode* _tmp0_;
		GXmlGDocument* doc = NULL;
		GXmlGDocument* _tmp1_;
		GXmlNode* _tmp2_;
		GXmlNode* _tmp3_;
		gchar* _tmp4_;
		gchar* _tmp5_;
		gchar* _tmp6_;
		gchar* _tmp7_;
		GXmlElement* element = NULL;
		GXmlNode* _tmp8_;
		GXmlNode* _tmp9_;
		GXmlElement* _tmp10_;
		GXmlNode* b = NULL;
		GXmlNode* _tmp11_;
		GXmlNode* s = NULL;
		GXmlNode* _tmp12_;
#line 41 "SerializablePropertyIntTest.vala"
		_tmp0_ = serializable_property_int_test_int_node_new ();
#line 41 "SerializablePropertyIntTest.vala"
		bn = _tmp0_;
#line 42 "SerializablePropertyIntTest.vala"
		_tmp1_ = gxml_gdocument_new ();
#line 42 "SerializablePropertyIntTest.vala"
		doc = _tmp1_;
#line 43 "SerializablePropertyIntTest.vala"
		_tmp2_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) bn, (GXmlNode*) doc, &_inner_error0_);
#line 43 "SerializablePropertyIntTest.vala"
		_tmp3_ = _tmp2_;
#line 43 "SerializablePropertyIntTest.vala"
		_g_object_unref0 (_tmp3_);
#line 43 "SerializablePropertyIntTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 43 "SerializablePropertyIntTest.vala"
			_g_object_unref0 (doc);
#line 43 "SerializablePropertyIntTest.vala"
			_g_object_unref0 (bn);
#line 203 "SerializablePropertyIntTest.c"
			goto __catch307_g_error;
		}
#line 44 "SerializablePropertyIntTest.vala"
		_tmp4_ = gxml_gnode_to_string ((GXmlGNode*) doc);
#line 44 "SerializablePropertyIntTest.vala"
		_tmp5_ = _tmp4_;
#line 44 "SerializablePropertyIntTest.vala"
		_tmp6_ = g_strconcat ("XML:\n", _tmp5_, NULL);
#line 44 "SerializablePropertyIntTest.vala"
		_tmp7_ = _tmp6_;
#line 44 "SerializablePropertyIntTest.vala"
		g_test_message ("%s", _tmp7_);
#line 44 "SerializablePropertyIntTest.vala"
		_g_free0 (_tmp7_);
#line 44 "SerializablePropertyIntTest.vala"
		_g_free0 (_tmp5_);
#line 45 "SerializablePropertyIntTest.vala"
		_tmp8_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 45 "SerializablePropertyIntTest.vala"
		_tmp9_ = _tmp8_;
#line 45 "SerializablePropertyIntTest.vala"
		_tmp10_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp9_, GXML_TYPE_ELEMENT) ? ((GXmlElement*) _tmp9_) : NULL;
#line 45 "SerializablePropertyIntTest.vala"
		if (_tmp10_ == NULL) {
#line 45 "SerializablePropertyIntTest.vala"
			_g_object_unref0 (_tmp9_);
#line 230 "SerializablePropertyIntTest.c"
		}
#line 45 "SerializablePropertyIntTest.vala"
		element = _tmp10_;
#line 46 "SerializablePropertyIntTest.vala"
		_tmp11_ = gxml_element_get_attr (element, "IntegerValue");
#line 46 "SerializablePropertyIntTest.vala"
		b = _tmp11_;
#line 47 "SerializablePropertyIntTest.vala"
		_vala_assert (b == NULL, "b == null");
#line 48 "SerializablePropertyIntTest.vala"
		_tmp12_ = gxml_element_get_attr (element, "name");
#line 48 "SerializablePropertyIntTest.vala"
		s = _tmp12_;
#line 49 "SerializablePropertyIntTest.vala"
		_vala_assert (s == NULL, "s == null");
#line 40 "SerializablePropertyIntTest.vala"
		_g_object_unref0 (s);
#line 40 "SerializablePropertyIntTest.vala"
		_g_object_unref0 (b);
#line 40 "SerializablePropertyIntTest.vala"
		_g_object_unref0 (element);
#line 40 "SerializablePropertyIntTest.vala"
		_g_object_unref0 (doc);
#line 40 "SerializablePropertyIntTest.vala"
		_g_object_unref0 (bn);
#line 256 "SerializablePropertyIntTest.c"
	}
	goto __finally307;
	__catch307_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp13_;
		const gchar* _tmp14_;
		gchar* _tmp15_;
		gchar* _tmp16_;
#line 40 "SerializablePropertyIntTest.vala"
		e = _inner_error0_;
#line 40 "SerializablePropertyIntTest.vala"
		_inner_error0_ = NULL;
#line 51 "SerializablePropertyIntTest.vala"
		_tmp13_ = e->message;
#line 51 "SerializablePropertyIntTest.vala"
		_tmp14_ = string_to_string (_tmp13_);
#line 51 "SerializablePropertyIntTest.vala"
		_tmp15_ = g_strconcat ("ERROR: ", _tmp14_, NULL);
#line 51 "SerializablePropertyIntTest.vala"
		_tmp16_ = _tmp15_;
#line 51 "SerializablePropertyIntTest.vala"
		g_test_message ("%s", _tmp16_);
#line 51 "SerializablePropertyIntTest.vala"
		_g_free0 (_tmp16_);
#line 52 "SerializablePropertyIntTest.vala"
		g_assert_not_reached ();
#line 40 "SerializablePropertyIntTest.vala"
		_g_error_free0 (e);
#line 286 "SerializablePropertyIntTest.c"
	}
	__finally307:
#line 40 "SerializablePropertyIntTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 40 "SerializablePropertyIntTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 40 "SerializablePropertyIntTest.vala"
		g_clear_error (&_inner_error0_);
#line 40 "SerializablePropertyIntTest.vala"
		return;
#line 297 "SerializablePropertyIntTest.c"
	}
}

static void
___lambda252__gtest_func (void)
{
#line 38 "SerializablePropertyIntTest.vala"
	__lambda252_ ();
#line 306 "SerializablePropertyIntTest.c"
}

static void
__lambda253_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		SerializablePropertyIntTestIntNode* bn = NULL;
		SerializablePropertyIntTestIntNode* _tmp0_;
		GXmlGDocument* doc = NULL;
		GXmlGDocument* _tmp1_;
		SerializablePropertyIntTestIntNode* _tmp2_;
		GXmlGDocument* _tmp3_;
		GXmlNode* _tmp4_;
		GXmlNode* _tmp5_;
		GXmlGDocument* _tmp6_;
		gchar* _tmp7_;
		gchar* _tmp8_;
		gchar* _tmp9_;
		gchar* _tmp10_;
		GXmlElement* element = NULL;
		GXmlGDocument* _tmp11_;
		GXmlNode* _tmp12_;
		GXmlNode* _tmp13_;
		GXmlElement* _tmp14_;
		GXmlNode* b = NULL;
		GXmlElement* _tmp15_;
		GXmlNode* _tmp16_;
		GXmlNode* _tmp17_;
		GXmlNode* s = NULL;
		GXmlElement* _tmp18_;
		GXmlNode* _tmp19_;
		GXmlNode* _tmp20_;
		SerializablePropertyIntTestIntNode* _tmp21_;
		GXmlSerializableInt* _tmp22_;
		GXmlSerializableInt* _tmp23_;
		SerializablePropertyIntTestIntNode* _tmp24_;
		GXmlSerializableInt* _tmp25_;
		GXmlSerializableInt* _tmp26_;
		GXmlGDocument* doc2 = NULL;
		GXmlGDocument* _tmp27_;
		SerializablePropertyIntTestIntNode* _tmp28_;
		GXmlGDocument* _tmp29_;
		GXmlNode* _tmp30_;
		GXmlNode* _tmp31_;
		GXmlGDocument* _tmp32_;
		gchar* _tmp33_;
		gchar* _tmp34_;
		gchar* _tmp35_;
		gchar* _tmp36_;
		GXmlElement* element2 = NULL;
		GXmlGDocument* _tmp37_;
		GXmlNode* _tmp38_;
		GXmlNode* _tmp39_;
		GXmlElement* _tmp40_;
		GXmlNode* b2 = NULL;
		GXmlElement* _tmp41_;
		GXmlNode* _tmp42_;
		GXmlNode* _tmp43_;
		GXmlNode* _tmp44_;
		gchar* _tmp45_;
		gchar* _tmp46_;
		gchar* _tmp47_;
		SerializablePropertyIntTestIntNode* _tmp48_;
		GXmlSerializableInt* _tmp49_;
		GXmlSerializableInt* _tmp50_;
		GXmlGDocument* doc3 = NULL;
		GXmlGDocument* _tmp51_;
		SerializablePropertyIntTestIntNode* _tmp52_;
		GXmlGDocument* _tmp53_;
		GXmlNode* _tmp54_;
		GXmlNode* _tmp55_;
		GXmlGDocument* _tmp56_;
		gchar* _tmp57_;
		gchar* _tmp58_;
		gchar* _tmp59_;
		gchar* _tmp60_;
		GXmlElement* element3 = NULL;
		GXmlGDocument* _tmp61_;
		GXmlNode* _tmp62_;
		GXmlNode* _tmp63_;
		GXmlElement* _tmp64_;
		GXmlNode* b3 = NULL;
		GXmlElement* _tmp65_;
		GXmlNode* _tmp66_;
		GXmlNode* _tmp67_;
		GXmlNode* _tmp68_;
		gchar* _tmp69_;
		gchar* _tmp70_;
		gchar* _tmp71_;
		SerializablePropertyIntTestIntNode* _tmp72_;
		GXmlSerializableInt* _tmp73_;
		GXmlSerializableInt* _tmp74_;
		GXmlGDocument* doc4 = NULL;
		GXmlGDocument* _tmp75_;
		SerializablePropertyIntTestIntNode* _tmp76_;
		GXmlGDocument* _tmp77_;
		GXmlNode* _tmp78_;
		GXmlNode* _tmp79_;
		GXmlGDocument* _tmp80_;
		gchar* _tmp81_;
		gchar* _tmp82_;
		gchar* _tmp83_;
		gchar* _tmp84_;
		GXmlElement* element4 = NULL;
		GXmlGDocument* _tmp85_;
		GXmlNode* _tmp86_;
		GXmlNode* _tmp87_;
		GXmlElement* _tmp88_;
		GXmlNode* b4 = NULL;
		GXmlNode* _tmp89_;
#line 58 "SerializablePropertyIntTest.vala"
		_tmp0_ = serializable_property_int_test_int_node_new ();
#line 58 "SerializablePropertyIntTest.vala"
		bn = _tmp0_;
#line 59 "SerializablePropertyIntTest.vala"
		_tmp1_ = gxml_gdocument_new ();
#line 59 "SerializablePropertyIntTest.vala"
		doc = _tmp1_;
#line 60 "SerializablePropertyIntTest.vala"
		_tmp2_ = bn;
#line 60 "SerializablePropertyIntTest.vala"
		_tmp3_ = doc;
#line 60 "SerializablePropertyIntTest.vala"
		_tmp4_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) _tmp2_, (GXmlNode*) _tmp3_, &_inner_error0_);
#line 60 "SerializablePropertyIntTest.vala"
		_tmp5_ = _tmp4_;
#line 60 "SerializablePropertyIntTest.vala"
		_g_object_unref0 (_tmp5_);
#line 60 "SerializablePropertyIntTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 60 "SerializablePropertyIntTest.vala"
			_g_object_unref0 (doc);
#line 60 "SerializablePropertyIntTest.vala"
			_g_object_unref0 (bn);
#line 442 "SerializablePropertyIntTest.c"
			goto __catch308_g_error;
		}
#line 61 "SerializablePropertyIntTest.vala"
		_tmp6_ = doc;
#line 61 "SerializablePropertyIntTest.vala"
		_tmp7_ = gxml_gnode_to_string ((GXmlGNode*) _tmp6_);
#line 61 "SerializablePropertyIntTest.vala"
		_tmp8_ = _tmp7_;
#line 61 "SerializablePropertyIntTest.vala"
		_tmp9_ = g_strconcat ("XML:\n", _tmp8_, NULL);
#line 61 "SerializablePropertyIntTest.vala"
		_tmp10_ = _tmp9_;
#line 61 "SerializablePropertyIntTest.vala"
		g_test_message ("%s", _tmp10_);
#line 61 "SerializablePropertyIntTest.vala"
		_g_free0 (_tmp10_);
#line 61 "SerializablePropertyIntTest.vala"
		_g_free0 (_tmp8_);
#line 62 "SerializablePropertyIntTest.vala"
		_tmp11_ = doc;
#line 62 "SerializablePropertyIntTest.vala"
		_tmp12_ = gxml_document_get_root ((GXmlDocument*) _tmp11_);
#line 62 "SerializablePropertyIntTest.vala"
		_tmp13_ = _tmp12_;
#line 62 "SerializablePropertyIntTest.vala"
		_tmp14_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp13_, GXML_TYPE_ELEMENT) ? ((GXmlElement*) _tmp13_) : NULL;
#line 62 "SerializablePropertyIntTest.vala"
		if (_tmp14_ == NULL) {
#line 62 "SerializablePropertyIntTest.vala"
			_g_object_unref0 (_tmp13_);
#line 473 "SerializablePropertyIntTest.c"
		}
#line 62 "SerializablePropertyIntTest.vala"
		element = _tmp14_;
#line 63 "SerializablePropertyIntTest.vala"
		_tmp15_ = element;
#line 63 "SerializablePropertyIntTest.vala"
		_tmp16_ = gxml_element_get_attr (_tmp15_, "IntegerValue");
#line 63 "SerializablePropertyIntTest.vala"
		b = _tmp16_;
#line 64 "SerializablePropertyIntTest.vala"
		_tmp17_ = b;
#line 64 "SerializablePropertyIntTest.vala"
		_vala_assert (_tmp17_ == NULL, "b == null");
#line 65 "SerializablePropertyIntTest.vala"
		_tmp18_ = element;
#line 65 "SerializablePropertyIntTest.vala"
		_tmp19_ = gxml_element_get_attr (_tmp18_, "name");
#line 65 "SerializablePropertyIntTest.vala"
		s = _tmp19_;
#line 66 "SerializablePropertyIntTest.vala"
		_tmp20_ = s;
#line 66 "SerializablePropertyIntTest.vala"
		_vala_assert (_tmp20_ == NULL, "s == null");
#line 68 "SerializablePropertyIntTest.vala"
		_tmp21_ = bn;
#line 68 "SerializablePropertyIntTest.vala"
		_tmp22_ = gxml_serializable_int_new ();
#line 68 "SerializablePropertyIntTest.vala"
		_tmp23_ = _tmp22_;
#line 68 "SerializablePropertyIntTest.vala"
		serializable_property_int_test_int_node_set_integer (_tmp21_, _tmp23_);
#line 68 "SerializablePropertyIntTest.vala"
		_g_object_unref0 (_tmp23_);
#line 70 "SerializablePropertyIntTest.vala"
		_tmp24_ = bn;
#line 70 "SerializablePropertyIntTest.vala"
		_tmp25_ = serializable_property_int_test_int_node_get_integer (_tmp24_);
#line 70 "SerializablePropertyIntTest.vala"
		_tmp26_ = _tmp25_;
#line 70 "SerializablePropertyIntTest.vala"
		gxml_serializable_int_set_value (_tmp26_, 233);
#line 71 "SerializablePropertyIntTest.vala"
		_tmp27_ = gxml_gdocument_new ();
#line 71 "SerializablePropertyIntTest.vala"
		doc2 = _tmp27_;
#line 72 "SerializablePropertyIntTest.vala"
		_tmp28_ = bn;
#line 72 "SerializablePropertyIntTest.vala"
		_tmp29_ = doc2;
#line 72 "SerializablePropertyIntTest.vala"
		_tmp30_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) _tmp28_, (GXmlNode*) _tmp29_, &_inner_error0_);
#line 72 "SerializablePropertyIntTest.vala"
		_tmp31_ = _tmp30_;
#line 72 "SerializablePropertyIntTest.vala"
		_g_object_unref0 (_tmp31_);
#line 72 "SerializablePropertyIntTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 72 "SerializablePropertyIntTest.vala"
			_g_object_unref0 (doc2);
#line 72 "SerializablePropertyIntTest.vala"
			_g_object_unref0 (s);
#line 72 "SerializablePropertyIntTest.vala"
			_g_object_unref0 (b);
#line 72 "SerializablePropertyIntTest.vala"
			_g_object_unref0 (element);
#line 72 "SerializablePropertyIntTest.vala"
			_g_object_unref0 (doc);
#line 72 "SerializablePropertyIntTest.vala"
			_g_object_unref0 (bn);
#line 543 "SerializablePropertyIntTest.c"
			goto __catch308_g_error;
		}
#line 73 "SerializablePropertyIntTest.vala"
		_tmp32_ = doc2;
#line 73 "SerializablePropertyIntTest.vala"
		_tmp33_ = gxml_gnode_to_string ((GXmlGNode*) _tmp32_);
#line 73 "SerializablePropertyIntTest.vala"
		_tmp34_ = _tmp33_;
#line 73 "SerializablePropertyIntTest.vala"
		_tmp35_ = g_strconcat ("XML2:\n", _tmp34_, NULL);
#line 73 "SerializablePropertyIntTest.vala"
		_tmp36_ = _tmp35_;
#line 73 "SerializablePropertyIntTest.vala"
		g_test_message ("%s", _tmp36_);
#line 73 "SerializablePropertyIntTest.vala"
		_g_free0 (_tmp36_);
#line 73 "SerializablePropertyIntTest.vala"
		_g_free0 (_tmp34_);
#line 74 "SerializablePropertyIntTest.vala"
		_tmp37_ = doc2;
#line 74 "SerializablePropertyIntTest.vala"
		_tmp38_ = gxml_document_get_root ((GXmlDocument*) _tmp37_);
#line 74 "SerializablePropertyIntTest.vala"
		_tmp39_ = _tmp38_;
#line 74 "SerializablePropertyIntTest.vala"
		_tmp40_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp39_, GXML_TYPE_ELEMENT) ? ((GXmlElement*) _tmp39_) : NULL;
#line 74 "SerializablePropertyIntTest.vala"
		if (_tmp40_ == NULL) {
#line 74 "SerializablePropertyIntTest.vala"
			_g_object_unref0 (_tmp39_);
#line 574 "SerializablePropertyIntTest.c"
		}
#line 74 "SerializablePropertyIntTest.vala"
		element2 = _tmp40_;
#line 75 "SerializablePropertyIntTest.vala"
		_tmp41_ = element2;
#line 75 "SerializablePropertyIntTest.vala"
		_tmp42_ = gxml_element_get_attr (_tmp41_, "IntegerValue");
#line 75 "SerializablePropertyIntTest.vala"
		b2 = _tmp42_;
#line 76 "SerializablePropertyIntTest.vala"
		_tmp43_ = b2;
#line 76 "SerializablePropertyIntTest.vala"
		_vala_assert (_tmp43_ != NULL, "b2 != null");
#line 77 "SerializablePropertyIntTest.vala"
		_tmp44_ = b2;
#line 77 "SerializablePropertyIntTest.vala"
		_tmp45_ = gxml_node_get_value (_tmp44_);
#line 77 "SerializablePropertyIntTest.vala"
		_tmp46_ = _tmp45_;
#line 77 "SerializablePropertyIntTest.vala"
		_tmp47_ = _tmp46_;
#line 77 "SerializablePropertyIntTest.vala"
		_vala_assert (g_strcmp0 (_tmp47_, "233") == 0, "b2.value == \"233\"");
#line 77 "SerializablePropertyIntTest.vala"
		_g_free0 (_tmp47_);
#line 79 "SerializablePropertyIntTest.vala"
		_tmp48_ = bn;
#line 79 "SerializablePropertyIntTest.vala"
		_tmp49_ = serializable_property_int_test_int_node_get_integer (_tmp48_);
#line 79 "SerializablePropertyIntTest.vala"
		_tmp50_ = _tmp49_;
#line 79 "SerializablePropertyIntTest.vala"
		gxml_serializable_int_set_value (_tmp50_, -1);
#line 80 "SerializablePropertyIntTest.vala"
		_tmp51_ = gxml_gdocument_new ();
#line 80 "SerializablePropertyIntTest.vala"
		doc3 = _tmp51_;
#line 81 "SerializablePropertyIntTest.vala"
		_tmp52_ = bn;
#line 81 "SerializablePropertyIntTest.vala"
		_tmp53_ = doc3;
#line 81 "SerializablePropertyIntTest.vala"
		_tmp54_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) _tmp52_, (GXmlNode*) _tmp53_, &_inner_error0_);
#line 81 "SerializablePropertyIntTest.vala"
		_tmp55_ = _tmp54_;
#line 81 "SerializablePropertyIntTest.vala"
		_g_object_unref0 (_tmp55_);
#line 81 "SerializablePropertyIntTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 81 "SerializablePropertyIntTest.vala"
			_g_object_unref0 (doc3);
#line 81 "SerializablePropertyIntTest.vala"
			_g_object_unref0 (b2);
#line 81 "SerializablePropertyIntTest.vala"
			_g_object_unref0 (element2);
#line 81 "SerializablePropertyIntTest.vala"
			_g_object_unref0 (doc2);
#line 81 "SerializablePropertyIntTest.vala"
			_g_object_unref0 (s);
#line 81 "SerializablePropertyIntTest.vala"
			_g_object_unref0 (b);
#line 81 "SerializablePropertyIntTest.vala"
			_g_object_unref0 (element);
#line 81 "SerializablePropertyIntTest.vala"
			_g_object_unref0 (doc);
#line 81 "SerializablePropertyIntTest.vala"
			_g_object_unref0 (bn);
#line 642 "SerializablePropertyIntTest.c"
			goto __catch308_g_error;
		}
#line 82 "SerializablePropertyIntTest.vala"
		_tmp56_ = doc3;
#line 82 "SerializablePropertyIntTest.vala"
		_tmp57_ = gxml_gnode_to_string ((GXmlGNode*) _tmp56_);
#line 82 "SerializablePropertyIntTest.vala"
		_tmp58_ = _tmp57_;
#line 82 "SerializablePropertyIntTest.vala"
		_tmp59_ = g_strconcat ("XML3:\n", _tmp58_, NULL);
#line 82 "SerializablePropertyIntTest.vala"
		_tmp60_ = _tmp59_;
#line 82 "SerializablePropertyIntTest.vala"
		g_test_message ("%s", _tmp60_);
#line 82 "SerializablePropertyIntTest.vala"
		_g_free0 (_tmp60_);
#line 82 "SerializablePropertyIntTest.vala"
		_g_free0 (_tmp58_);
#line 83 "SerializablePropertyIntTest.vala"
		_tmp61_ = doc3;
#line 83 "SerializablePropertyIntTest.vala"
		_tmp62_ = gxml_document_get_root ((GXmlDocument*) _tmp61_);
#line 83 "SerializablePropertyIntTest.vala"
		_tmp63_ = _tmp62_;
#line 83 "SerializablePropertyIntTest.vala"
		_tmp64_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp63_, GXML_TYPE_ELEMENT) ? ((GXmlElement*) _tmp63_) : NULL;
#line 83 "SerializablePropertyIntTest.vala"
		if (_tmp64_ == NULL) {
#line 83 "SerializablePropertyIntTest.vala"
			_g_object_unref0 (_tmp63_);
#line 673 "SerializablePropertyIntTest.c"
		}
#line 83 "SerializablePropertyIntTest.vala"
		element3 = _tmp64_;
#line 84 "SerializablePropertyIntTest.vala"
		_tmp65_ = element3;
#line 84 "SerializablePropertyIntTest.vala"
		_tmp66_ = gxml_element_get_attr (_tmp65_, "IntegerValue");
#line 84 "SerializablePropertyIntTest.vala"
		b3 = _tmp66_;
#line 85 "SerializablePropertyIntTest.vala"
		_tmp67_ = b3;
#line 85 "SerializablePropertyIntTest.vala"
		_vala_assert (_tmp67_ != NULL, "b3 != null");
#line 86 "SerializablePropertyIntTest.vala"
		_tmp68_ = b3;
#line 86 "SerializablePropertyIntTest.vala"
		_tmp69_ = gxml_node_get_value (_tmp68_);
#line 86 "SerializablePropertyIntTest.vala"
		_tmp70_ = _tmp69_;
#line 86 "SerializablePropertyIntTest.vala"
		_tmp71_ = _tmp70_;
#line 86 "SerializablePropertyIntTest.vala"
		_vala_assert (g_strcmp0 (_tmp71_, "-1") == 0, "b3.value == \"-1\"");
#line 86 "SerializablePropertyIntTest.vala"
		_g_free0 (_tmp71_);
#line 88 "SerializablePropertyIntTest.vala"
		_tmp72_ = bn;
#line 88 "SerializablePropertyIntTest.vala"
		_tmp73_ = serializable_property_int_test_int_node_get_integer (_tmp72_);
#line 88 "SerializablePropertyIntTest.vala"
		_tmp74_ = _tmp73_;
#line 88 "SerializablePropertyIntTest.vala"
		gxml_serializable_property_set_serializable_property_value ((GXmlSerializableProperty*) _tmp74_, NULL);
#line 89 "SerializablePropertyIntTest.vala"
		_tmp75_ = gxml_gdocument_new ();
#line 89 "SerializablePropertyIntTest.vala"
		doc4 = _tmp75_;
#line 90 "SerializablePropertyIntTest.vala"
		_tmp76_ = bn;
#line 90 "SerializablePropertyIntTest.vala"
		_tmp77_ = doc4;
#line 90 "SerializablePropertyIntTest.vala"
		_tmp78_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) _tmp76_, (GXmlNode*) _tmp77_, &_inner_error0_);
#line 90 "SerializablePropertyIntTest.vala"
		_tmp79_ = _tmp78_;
#line 90 "SerializablePropertyIntTest.vala"
		_g_object_unref0 (_tmp79_);
#line 90 "SerializablePropertyIntTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 90 "SerializablePropertyIntTest.vala"
			_g_object_unref0 (doc4);
#line 90 "SerializablePropertyIntTest.vala"
			_g_object_unref0 (b3);
#line 90 "SerializablePropertyIntTest.vala"
			_g_object_unref0 (element3);
#line 90 "SerializablePropertyIntTest.vala"
			_g_object_unref0 (doc3);
#line 90 "SerializablePropertyIntTest.vala"
			_g_object_unref0 (b2);
#line 90 "SerializablePropertyIntTest.vala"
			_g_object_unref0 (element2);
#line 90 "SerializablePropertyIntTest.vala"
			_g_object_unref0 (doc2);
#line 90 "SerializablePropertyIntTest.vala"
			_g_object_unref0 (s);
#line 90 "SerializablePropertyIntTest.vala"
			_g_object_unref0 (b);
#line 90 "SerializablePropertyIntTest.vala"
			_g_object_unref0 (element);
#line 90 "SerializablePropertyIntTest.vala"
			_g_object_unref0 (doc);
#line 90 "SerializablePropertyIntTest.vala"
			_g_object_unref0 (bn);
#line 747 "SerializablePropertyIntTest.c"
			goto __catch308_g_error;
		}
#line 91 "SerializablePropertyIntTest.vala"
		_tmp80_ = doc4;
#line 91 "SerializablePropertyIntTest.vala"
		_tmp81_ = gxml_gnode_to_string ((GXmlGNode*) _tmp80_);
#line 91 "SerializablePropertyIntTest.vala"
		_tmp82_ = _tmp81_;
#line 91 "SerializablePropertyIntTest.vala"
		_tmp83_ = g_strconcat ("XML3:\n", _tmp82_, NULL);
#line 91 "SerializablePropertyIntTest.vala"
		_tmp84_ = _tmp83_;
#line 91 "SerializablePropertyIntTest.vala"
		g_test_message ("%s", _tmp84_);
#line 91 "SerializablePropertyIntTest.vala"
		_g_free0 (_tmp84_);
#line 91 "SerializablePropertyIntTest.vala"
		_g_free0 (_tmp82_);
#line 92 "SerializablePropertyIntTest.vala"
		_tmp85_ = doc4;
#line 92 "SerializablePropertyIntTest.vala"
		_tmp86_ = gxml_document_get_root ((GXmlDocument*) _tmp85_);
#line 92 "SerializablePropertyIntTest.vala"
		_tmp87_ = _tmp86_;
#line 92 "SerializablePropertyIntTest.vala"
		_tmp88_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp87_, GXML_TYPE_ELEMENT) ? ((GXmlElement*) _tmp87_) : NULL;
#line 92 "SerializablePropertyIntTest.vala"
		if (_tmp88_ == NULL) {
#line 92 "SerializablePropertyIntTest.vala"
			_g_object_unref0 (_tmp87_);
#line 778 "SerializablePropertyIntTest.c"
		}
#line 92 "SerializablePropertyIntTest.vala"
		element4 = _tmp88_;
#line 93 "SerializablePropertyIntTest.vala"
		_tmp89_ = gxml_element_get_attr (element4, "IntegerValue");
#line 93 "SerializablePropertyIntTest.vala"
		b4 = _tmp89_;
#line 94 "SerializablePropertyIntTest.vala"
		_vala_assert (b4 == NULL, "b4 == null");
#line 57 "SerializablePropertyIntTest.vala"
		_g_object_unref0 (b4);
#line 57 "SerializablePropertyIntTest.vala"
		_g_object_unref0 (element4);
#line 57 "SerializablePropertyIntTest.vala"
		_g_object_unref0 (doc4);
#line 57 "SerializablePropertyIntTest.vala"
		_g_object_unref0 (b3);
#line 57 "SerializablePropertyIntTest.vala"
		_g_object_unref0 (element3);
#line 57 "SerializablePropertyIntTest.vala"
		_g_object_unref0 (doc3);
#line 57 "SerializablePropertyIntTest.vala"
		_g_object_unref0 (b2);
#line 57 "SerializablePropertyIntTest.vala"
		_g_object_unref0 (element2);
#line 57 "SerializablePropertyIntTest.vala"
		_g_object_unref0 (doc2);
#line 57 "SerializablePropertyIntTest.vala"
		_g_object_unref0 (s);
#line 57 "SerializablePropertyIntTest.vala"
		_g_object_unref0 (b);
#line 57 "SerializablePropertyIntTest.vala"
		_g_object_unref0 (element);
#line 57 "SerializablePropertyIntTest.vala"
		_g_object_unref0 (doc);
#line 57 "SerializablePropertyIntTest.vala"
		_g_object_unref0 (bn);
#line 816 "SerializablePropertyIntTest.c"
	}
	goto __finally308;
	__catch308_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp90_;
		const gchar* _tmp91_;
		gchar* _tmp92_;
		gchar* _tmp93_;
#line 57 "SerializablePropertyIntTest.vala"
		e = _inner_error0_;
#line 57 "SerializablePropertyIntTest.vala"
		_inner_error0_ = NULL;
#line 96 "SerializablePropertyIntTest.vala"
		_tmp90_ = e->message;
#line 96 "SerializablePropertyIntTest.vala"
		_tmp91_ = string_to_string (_tmp90_);
#line 96 "SerializablePropertyIntTest.vala"
		_tmp92_ = g_strconcat ("ERROR: ", _tmp91_, NULL);
#line 96 "SerializablePropertyIntTest.vala"
		_tmp93_ = _tmp92_;
#line 96 "SerializablePropertyIntTest.vala"
		g_test_message ("%s", _tmp93_);
#line 96 "SerializablePropertyIntTest.vala"
		_g_free0 (_tmp93_);
#line 97 "SerializablePropertyIntTest.vala"
		g_assert_not_reached ();
#line 57 "SerializablePropertyIntTest.vala"
		_g_error_free0 (e);
#line 846 "SerializablePropertyIntTest.c"
	}
	__finally308:
#line 57 "SerializablePropertyIntTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 57 "SerializablePropertyIntTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 57 "SerializablePropertyIntTest.vala"
		g_clear_error (&_inner_error0_);
#line 57 "SerializablePropertyIntTest.vala"
		return;
#line 857 "SerializablePropertyIntTest.c"
	}
}

static void
___lambda253__gtest_func (void)
{
#line 55 "SerializablePropertyIntTest.vala"
	__lambda253_ ();
#line 866 "SerializablePropertyIntTest.c"
}

static void
__lambda254_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlGDocument* doc1 = NULL;
		GXmlGDocument* _tmp0_;
		SerializablePropertyIntTestIntNode* i = NULL;
		SerializablePropertyIntTestIntNode* _tmp1_;
		SerializablePropertyIntTestIntNode* _tmp2_;
		GXmlGDocument* _tmp3_;
		SerializablePropertyIntTestIntNode* _tmp4_;
		GXmlSerializableInt* _tmp5_;
		GXmlSerializableInt* _tmp6_;
		gchar* _tmp7_;
		gchar* _tmp8_;
		gchar* _tmp9_;
		gchar* _tmp10_;
		SerializablePropertyIntTestIntNode* _tmp11_;
		GXmlSerializableInt* _tmp12_;
		GXmlSerializableInt* _tmp13_;
		gchar* _tmp14_;
		gchar* _tmp15_;
		SerializablePropertyIntTestIntNode* _tmp16_;
		GXmlSerializableInt* _tmp17_;
		GXmlSerializableInt* _tmp18_;
		gchar* _tmp19_;
		gchar* _tmp20_;
		gchar* _tmp21_;
		gchar* _tmp22_;
		gint iv = 0;
		SerializablePropertyIntTestIntNode* _tmp23_;
		GXmlSerializableInt* _tmp24_;
		GXmlSerializableInt* _tmp25_;
		gchar* _tmp26_;
		gchar* _tmp27_;
		gchar* _tmp28_;
		gchar* _tmp29_;
		SerializablePropertyIntTestIntNode* _tmp30_;
		GXmlSerializableInt* _tmp31_;
		GXmlSerializableInt* _tmp32_;
#line 103 "SerializablePropertyIntTest.vala"
		_tmp0_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n" \
"                       <IntNode IntegerValue=\"1416\"/>", 0, &_inner_error0_);
#line 103 "SerializablePropertyIntTest.vala"
		doc1 = _tmp0_;
#line 103 "SerializablePropertyIntTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 916 "SerializablePropertyIntTest.c"
			goto __catch309_g_error;
		}
#line 105 "SerializablePropertyIntTest.vala"
		_tmp1_ = serializable_property_int_test_int_node_new ();
#line 105 "SerializablePropertyIntTest.vala"
		i = _tmp1_;
#line 106 "SerializablePropertyIntTest.vala"
		_tmp2_ = i;
#line 106 "SerializablePropertyIntTest.vala"
		_tmp3_ = doc1;
#line 106 "SerializablePropertyIntTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp2_, (GXmlNode*) _tmp3_, &_inner_error0_);
#line 106 "SerializablePropertyIntTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 106 "SerializablePropertyIntTest.vala"
			_g_object_unref0 (i);
#line 106 "SerializablePropertyIntTest.vala"
			_g_object_unref0 (doc1);
#line 935 "SerializablePropertyIntTest.c"
			goto __catch309_g_error;
		}
#line 107 "SerializablePropertyIntTest.vala"
		_tmp4_ = i;
#line 107 "SerializablePropertyIntTest.vala"
		_tmp5_ = serializable_property_int_test_int_node_get_integer (_tmp4_);
#line 107 "SerializablePropertyIntTest.vala"
		_tmp6_ = _tmp5_;
#line 107 "SerializablePropertyIntTest.vala"
		_tmp7_ = gxml_serializable_property_get_serializable_property_value ((GXmlSerializableProperty*) _tmp6_);
#line 107 "SerializablePropertyIntTest.vala"
		_tmp8_ = _tmp7_;
#line 107 "SerializablePropertyIntTest.vala"
		_tmp9_ = g_strconcat ("Actual value: ", _tmp8_, NULL);
#line 107 "SerializablePropertyIntTest.vala"
		_tmp10_ = _tmp9_;
#line 107 "SerializablePropertyIntTest.vala"
		g_test_message ("%s", _tmp10_);
#line 107 "SerializablePropertyIntTest.vala"
		_g_free0 (_tmp10_);
#line 107 "SerializablePropertyIntTest.vala"
		_g_free0 (_tmp8_);
#line 108 "SerializablePropertyIntTest.vala"
		_tmp11_ = i;
#line 108 "SerializablePropertyIntTest.vala"
		_tmp12_ = serializable_property_int_test_int_node_get_integer (_tmp11_);
#line 108 "SerializablePropertyIntTest.vala"
		_tmp13_ = _tmp12_;
#line 108 "SerializablePropertyIntTest.vala"
		_tmp14_ = gxml_serializable_property_get_serializable_property_value ((GXmlSerializableProperty*) _tmp13_);
#line 108 "SerializablePropertyIntTest.vala"
		_tmp15_ = _tmp14_;
#line 108 "SerializablePropertyIntTest.vala"
		_vala_assert (g_strcmp0 (_tmp15_, "1416") == 0, "i.integer.get_serializable_property_value () == \"1416\"");
#line 108 "SerializablePropertyIntTest.vala"
		_g_free0 (_tmp15_);
#line 109 "SerializablePropertyIntTest.vala"
		_tmp16_ = i;
#line 109 "SerializablePropertyIntTest.vala"
		_tmp17_ = serializable_property_int_test_int_node_get_integer (_tmp16_);
#line 109 "SerializablePropertyIntTest.vala"
		_tmp18_ = _tmp17_;
#line 109 "SerializablePropertyIntTest.vala"
		_tmp19_ = g_strdup_printf ("%i", gxml_serializable_int_get_value (_tmp18_));
#line 109 "SerializablePropertyIntTest.vala"
		_tmp20_ = _tmp19_;
#line 109 "SerializablePropertyIntTest.vala"
		_tmp21_ = g_strconcat ("Actual value parse: ", _tmp20_, NULL);
#line 109 "SerializablePropertyIntTest.vala"
		_tmp22_ = _tmp21_;
#line 109 "SerializablePropertyIntTest.vala"
		g_test_message ("%s", _tmp22_);
#line 109 "SerializablePropertyIntTest.vala"
		_g_free0 (_tmp22_);
#line 109 "SerializablePropertyIntTest.vala"
		_g_free0 (_tmp20_);
#line 110 "SerializablePropertyIntTest.vala"
		_tmp23_ = i;
#line 110 "SerializablePropertyIntTest.vala"
		_tmp24_ = serializable_property_int_test_int_node_get_integer (_tmp23_);
#line 110 "SerializablePropertyIntTest.vala"
		_tmp25_ = _tmp24_;
#line 110 "SerializablePropertyIntTest.vala"
		iv = gxml_serializable_int_get_value (_tmp25_);
#line 111 "SerializablePropertyIntTest.vala"
		_tmp26_ = g_strdup_printf ("%i", iv);
#line 111 "SerializablePropertyIntTest.vala"
		_tmp27_ = _tmp26_;
#line 111 "SerializablePropertyIntTest.vala"
		_tmp28_ = g_strconcat ("Use from int, value:", _tmp27_, NULL);
#line 111 "SerializablePropertyIntTest.vala"
		_tmp29_ = _tmp28_;
#line 111 "SerializablePropertyIntTest.vala"
		g_test_message ("%s", _tmp29_);
#line 111 "SerializablePropertyIntTest.vala"
		_g_free0 (_tmp29_);
#line 111 "SerializablePropertyIntTest.vala"
		_g_free0 (_tmp27_);
#line 112 "SerializablePropertyIntTest.vala"
		_tmp30_ = i;
#line 112 "SerializablePropertyIntTest.vala"
		_tmp31_ = serializable_property_int_test_int_node_get_integer (_tmp30_);
#line 112 "SerializablePropertyIntTest.vala"
		_tmp32_ = _tmp31_;
#line 112 "SerializablePropertyIntTest.vala"
		_vala_assert (gxml_serializable_int_get_value (_tmp32_) == 1416, "i.integer.get_value () == 1416");
#line 102 "SerializablePropertyIntTest.vala"
		_g_object_unref0 (i);
#line 102 "SerializablePropertyIntTest.vala"
		_g_object_unref0 (doc1);
#line 1026 "SerializablePropertyIntTest.c"
	}
	goto __finally309;
	__catch309_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp33_;
		const gchar* _tmp34_;
		gchar* _tmp35_;
		gchar* _tmp36_;
#line 102 "SerializablePropertyIntTest.vala"
		e = _inner_error0_;
#line 102 "SerializablePropertyIntTest.vala"
		_inner_error0_ = NULL;
#line 114 "SerializablePropertyIntTest.vala"
		_tmp33_ = e->message;
#line 114 "SerializablePropertyIntTest.vala"
		_tmp34_ = string_to_string (_tmp33_);
#line 114 "SerializablePropertyIntTest.vala"
		_tmp35_ = g_strconcat ("ERROR: ", _tmp34_, NULL);
#line 114 "SerializablePropertyIntTest.vala"
		_tmp36_ = _tmp35_;
#line 114 "SerializablePropertyIntTest.vala"
		g_test_message ("%s", _tmp36_);
#line 114 "SerializablePropertyIntTest.vala"
		_g_free0 (_tmp36_);
#line 115 "SerializablePropertyIntTest.vala"
		g_assert_not_reached ();
#line 102 "SerializablePropertyIntTest.vala"
		_g_error_free0 (e);
#line 1056 "SerializablePropertyIntTest.c"
	}
	__finally309:
#line 102 "SerializablePropertyIntTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 102 "SerializablePropertyIntTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 102 "SerializablePropertyIntTest.vala"
		g_clear_error (&_inner_error0_);
#line 102 "SerializablePropertyIntTest.vala"
		return;
#line 1067 "SerializablePropertyIntTest.c"
	}
}

static void
___lambda254__gtest_func (void)
{
#line 100 "SerializablePropertyIntTest.vala"
	__lambda254_ ();
#line 1076 "SerializablePropertyIntTest.c"
}

static void
__lambda255_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlGDocument* doc1 = NULL;
		GXmlGDocument* _tmp0_;
		SerializablePropertyIntTestIntNode* i1 = NULL;
		SerializablePropertyIntTestIntNode* _tmp1_;
		SerializablePropertyIntTestIntNode* _tmp2_;
		GXmlGDocument* _tmp3_;
		SerializablePropertyIntTestIntNode* _tmp4_;
		GXmlSerializableInt* _tmp5_;
		GXmlSerializableInt* _tmp6_;
		gchar* _tmp7_;
		gchar* _tmp8_;
		gchar* _tmp9_;
		gchar* _tmp10_;
		SerializablePropertyIntTestIntNode* _tmp11_;
		GXmlSerializableInt* _tmp12_;
		GXmlSerializableInt* _tmp13_;
		gchar* _tmp14_;
		gchar* _tmp15_;
		SerializablePropertyIntTestIntNode* _tmp16_;
		GXmlSerializableInt* _tmp17_;
		GXmlSerializableInt* _tmp18_;
		gchar* _tmp19_;
		gchar* _tmp20_;
		gchar* _tmp21_;
		gchar* _tmp22_;
		SerializablePropertyIntTestIntNode* _tmp23_;
		GXmlSerializableInt* _tmp24_;
		GXmlSerializableInt* _tmp25_;
		GXmlGDocument* doc2 = NULL;
		GXmlGDocument* _tmp26_;
		SerializablePropertyIntTestIntNode* i2 = NULL;
		SerializablePropertyIntTestIntNode* _tmp27_;
		SerializablePropertyIntTestIntNode* _tmp28_;
		GXmlGDocument* _tmp29_;
		SerializablePropertyIntTestIntNode* _tmp30_;
		GXmlSerializableInt* _tmp31_;
		GXmlSerializableInt* _tmp32_;
		gchar* _tmp33_;
		gchar* _tmp34_;
		gchar* _tmp35_;
		gchar* _tmp36_;
		SerializablePropertyIntTestIntNode* _tmp37_;
		GXmlSerializableInt* _tmp38_;
		GXmlSerializableInt* _tmp39_;
		gchar* _tmp40_;
		gchar* _tmp41_;
		SerializablePropertyIntTestIntNode* _tmp42_;
		GXmlSerializableInt* _tmp43_;
		GXmlSerializableInt* _tmp44_;
		gchar* _tmp45_;
		gchar* _tmp46_;
		gchar* _tmp47_;
		gchar* _tmp48_;
		SerializablePropertyIntTestIntNode* _tmp49_;
		GXmlSerializableInt* _tmp50_;
		GXmlSerializableInt* _tmp51_;
		GXmlGDocument* doc3 = NULL;
		GXmlGDocument* _tmp52_;
		SerializablePropertyIntTestIntNode* i3 = NULL;
		SerializablePropertyIntTestIntNode* _tmp53_;
		SerializablePropertyIntTestIntNode* _tmp54_;
		GXmlGDocument* _tmp55_;
		SerializablePropertyIntTestIntNode* _tmp56_;
		GXmlSerializableInt* _tmp57_;
		GXmlSerializableInt* _tmp58_;
		gchar* _tmp59_;
		gchar* _tmp60_;
		gchar* _tmp61_;
		gchar* _tmp62_;
		SerializablePropertyIntTestIntNode* _tmp63_;
		GXmlSerializableInt* _tmp64_;
		GXmlSerializableInt* _tmp65_;
		gchar* _tmp66_;
		gchar* _tmp67_;
		SerializablePropertyIntTestIntNode* _tmp68_;
		GXmlSerializableInt* _tmp69_;
		GXmlSerializableInt* _tmp70_;
		gchar* _tmp71_;
		gchar* _tmp72_;
		gchar* _tmp73_;
		gchar* _tmp74_;
		SerializablePropertyIntTestIntNode* _tmp75_;
		GXmlSerializableInt* _tmp76_;
		GXmlSerializableInt* _tmp77_;
#line 121 "SerializablePropertyIntTest.vala"
		_tmp0_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n" \
"                       <IntNode IntegerValue=\"a\"/>", 0, &_inner_error0_);
#line 121 "SerializablePropertyIntTest.vala"
		doc1 = _tmp0_;
#line 121 "SerializablePropertyIntTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1174 "SerializablePropertyIntTest.c"
			goto __catch310_g_error;
		}
#line 123 "SerializablePropertyIntTest.vala"
		_tmp1_ = serializable_property_int_test_int_node_new ();
#line 123 "SerializablePropertyIntTest.vala"
		i1 = _tmp1_;
#line 124 "SerializablePropertyIntTest.vala"
		_tmp2_ = i1;
#line 124 "SerializablePropertyIntTest.vala"
		_tmp3_ = doc1;
#line 124 "SerializablePropertyIntTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp2_, (GXmlNode*) _tmp3_, &_inner_error0_);
#line 124 "SerializablePropertyIntTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 124 "SerializablePropertyIntTest.vala"
			_g_object_unref0 (i1);
#line 124 "SerializablePropertyIntTest.vala"
			_g_object_unref0 (doc1);
#line 1193 "SerializablePropertyIntTest.c"
			goto __catch310_g_error;
		}
#line 125 "SerializablePropertyIntTest.vala"
		_tmp4_ = i1;
#line 125 "SerializablePropertyIntTest.vala"
		_tmp5_ = serializable_property_int_test_int_node_get_integer (_tmp4_);
#line 125 "SerializablePropertyIntTest.vala"
		_tmp6_ = _tmp5_;
#line 125 "SerializablePropertyIntTest.vala"
		_tmp7_ = gxml_serializable_property_get_serializable_property_value ((GXmlSerializableProperty*) _tmp6_);
#line 125 "SerializablePropertyIntTest.vala"
		_tmp8_ = _tmp7_;
#line 125 "SerializablePropertyIntTest.vala"
		_tmp9_ = g_strconcat ("Actual value: ", _tmp8_, NULL);
#line 125 "SerializablePropertyIntTest.vala"
		_tmp10_ = _tmp9_;
#line 125 "SerializablePropertyIntTest.vala"
		g_test_message ("%s", _tmp10_);
#line 125 "SerializablePropertyIntTest.vala"
		_g_free0 (_tmp10_);
#line 125 "SerializablePropertyIntTest.vala"
		_g_free0 (_tmp8_);
#line 126 "SerializablePropertyIntTest.vala"
		_tmp11_ = i1;
#line 126 "SerializablePropertyIntTest.vala"
		_tmp12_ = serializable_property_int_test_int_node_get_integer (_tmp11_);
#line 126 "SerializablePropertyIntTest.vala"
		_tmp13_ = _tmp12_;
#line 126 "SerializablePropertyIntTest.vala"
		_tmp14_ = gxml_serializable_property_get_serializable_property_value ((GXmlSerializableProperty*) _tmp13_);
#line 126 "SerializablePropertyIntTest.vala"
		_tmp15_ = _tmp14_;
#line 126 "SerializablePropertyIntTest.vala"
		_vala_assert (g_strcmp0 (_tmp15_, "a") == 0, "i1.integer.get_serializable_property_value () == \"a\"");
#line 126 "SerializablePropertyIntTest.vala"
		_g_free0 (_tmp15_);
#line 127 "SerializablePropertyIntTest.vala"
		_tmp16_ = i1;
#line 127 "SerializablePropertyIntTest.vala"
		_tmp17_ = serializable_property_int_test_int_node_get_integer (_tmp16_);
#line 127 "SerializablePropertyIntTest.vala"
		_tmp18_ = _tmp17_;
#line 127 "SerializablePropertyIntTest.vala"
		_tmp19_ = g_strdup_printf ("%i", gxml_serializable_int_get_value (_tmp18_));
#line 127 "SerializablePropertyIntTest.vala"
		_tmp20_ = _tmp19_;
#line 127 "SerializablePropertyIntTest.vala"
		_tmp21_ = g_strconcat ("Actual value parse: ", _tmp20_, NULL);
#line 127 "SerializablePropertyIntTest.vala"
		_tmp22_ = _tmp21_;
#line 127 "SerializablePropertyIntTest.vala"
		g_test_message ("%s", _tmp22_);
#line 127 "SerializablePropertyIntTest.vala"
		_g_free0 (_tmp22_);
#line 127 "SerializablePropertyIntTest.vala"
		_g_free0 (_tmp20_);
#line 128 "SerializablePropertyIntTest.vala"
		_tmp23_ = i1;
#line 128 "SerializablePropertyIntTest.vala"
		_tmp24_ = serializable_property_int_test_int_node_get_integer (_tmp23_);
#line 128 "SerializablePropertyIntTest.vala"
		_tmp25_ = _tmp24_;
#line 128 "SerializablePropertyIntTest.vala"
		_vala_assert (gxml_serializable_int_get_value (_tmp25_) == 0, "i1.integer.get_value () == 0");
#line 129 "SerializablePropertyIntTest.vala"
		_tmp26_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n" \
"                       <IntNode IntegerValue=\"1.1\"/>", 0, &_inner_error0_);
#line 129 "SerializablePropertyIntTest.vala"
		doc2 = _tmp26_;
#line 129 "SerializablePropertyIntTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 129 "SerializablePropertyIntTest.vala"
			_g_object_unref0 (i1);
#line 129 "SerializablePropertyIntTest.vala"
			_g_object_unref0 (doc1);
#line 1268 "SerializablePropertyIntTest.c"
			goto __catch310_g_error;
		}
#line 131 "SerializablePropertyIntTest.vala"
		_tmp27_ = serializable_property_int_test_int_node_new ();
#line 131 "SerializablePropertyIntTest.vala"
		i2 = _tmp27_;
#line 132 "SerializablePropertyIntTest.vala"
		_tmp28_ = i2;
#line 132 "SerializablePropertyIntTest.vala"
		_tmp29_ = doc2;
#line 132 "SerializablePropertyIntTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp28_, (GXmlNode*) _tmp29_, &_inner_error0_);
#line 132 "SerializablePropertyIntTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 132 "SerializablePropertyIntTest.vala"
			_g_object_unref0 (i2);
#line 132 "SerializablePropertyIntTest.vala"
			_g_object_unref0 (doc2);
#line 132 "SerializablePropertyIntTest.vala"
			_g_object_unref0 (i1);
#line 132 "SerializablePropertyIntTest.vala"
			_g_object_unref0 (doc1);
#line 1291 "SerializablePropertyIntTest.c"
			goto __catch310_g_error;
		}
#line 133 "SerializablePropertyIntTest.vala"
		_tmp30_ = i2;
#line 133 "SerializablePropertyIntTest.vala"
		_tmp31_ = serializable_property_int_test_int_node_get_integer (_tmp30_);
#line 133 "SerializablePropertyIntTest.vala"
		_tmp32_ = _tmp31_;
#line 133 "SerializablePropertyIntTest.vala"
		_tmp33_ = gxml_serializable_property_get_serializable_property_value ((GXmlSerializableProperty*) _tmp32_);
#line 133 "SerializablePropertyIntTest.vala"
		_tmp34_ = _tmp33_;
#line 133 "SerializablePropertyIntTest.vala"
		_tmp35_ = g_strconcat ("Actual value: ", _tmp34_, NULL);
#line 133 "SerializablePropertyIntTest.vala"
		_tmp36_ = _tmp35_;
#line 133 "SerializablePropertyIntTest.vala"
		g_test_message ("%s", _tmp36_);
#line 133 "SerializablePropertyIntTest.vala"
		_g_free0 (_tmp36_);
#line 133 "SerializablePropertyIntTest.vala"
		_g_free0 (_tmp34_);
#line 134 "SerializablePropertyIntTest.vala"
		_tmp37_ = i2;
#line 134 "SerializablePropertyIntTest.vala"
		_tmp38_ = serializable_property_int_test_int_node_get_integer (_tmp37_);
#line 134 "SerializablePropertyIntTest.vala"
		_tmp39_ = _tmp38_;
#line 134 "SerializablePropertyIntTest.vala"
		_tmp40_ = gxml_serializable_property_get_serializable_property_value ((GXmlSerializableProperty*) _tmp39_);
#line 134 "SerializablePropertyIntTest.vala"
		_tmp41_ = _tmp40_;
#line 134 "SerializablePropertyIntTest.vala"
		_vala_assert (g_strcmp0 (_tmp41_, "1.1") == 0, "i2.integer.get_serializable_property_value () == \"1.1\"");
#line 134 "SerializablePropertyIntTest.vala"
		_g_free0 (_tmp41_);
#line 135 "SerializablePropertyIntTest.vala"
		_tmp42_ = i2;
#line 135 "SerializablePropertyIntTest.vala"
		_tmp43_ = serializable_property_int_test_int_node_get_integer (_tmp42_);
#line 135 "SerializablePropertyIntTest.vala"
		_tmp44_ = _tmp43_;
#line 135 "SerializablePropertyIntTest.vala"
		_tmp45_ = g_strdup_printf ("%i", gxml_serializable_int_get_value (_tmp44_));
#line 135 "SerializablePropertyIntTest.vala"
		_tmp46_ = _tmp45_;
#line 135 "SerializablePropertyIntTest.vala"
		_tmp47_ = g_strconcat ("Actual value parse: ", _tmp46_, NULL);
#line 135 "SerializablePropertyIntTest.vala"
		_tmp48_ = _tmp47_;
#line 135 "SerializablePropertyIntTest.vala"
		g_test_message ("%s", _tmp48_);
#line 135 "SerializablePropertyIntTest.vala"
		_g_free0 (_tmp48_);
#line 135 "SerializablePropertyIntTest.vala"
		_g_free0 (_tmp46_);
#line 136 "SerializablePropertyIntTest.vala"
		_tmp49_ = i2;
#line 136 "SerializablePropertyIntTest.vala"
		_tmp50_ = serializable_property_int_test_int_node_get_integer (_tmp49_);
#line 136 "SerializablePropertyIntTest.vala"
		_tmp51_ = _tmp50_;
#line 136 "SerializablePropertyIntTest.vala"
		_vala_assert (gxml_serializable_int_get_value (_tmp51_) == 1, "i2.integer.get_value () == 1");
#line 137 "SerializablePropertyIntTest.vala"
		_tmp52_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n" \
"                       <IntNode IntegerValue=\"1a\"/>", 0, &_inner_error0_);
#line 137 "SerializablePropertyIntTest.vala"
		doc3 = _tmp52_;
#line 137 "SerializablePropertyIntTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 137 "SerializablePropertyIntTest.vala"
			_g_object_unref0 (i2);
#line 137 "SerializablePropertyIntTest.vala"
			_g_object_unref0 (doc2);
#line 137 "SerializablePropertyIntTest.vala"
			_g_object_unref0 (i1);
#line 137 "SerializablePropertyIntTest.vala"
			_g_object_unref0 (doc1);
#line 1370 "SerializablePropertyIntTest.c"
			goto __catch310_g_error;
		}
#line 139 "SerializablePropertyIntTest.vala"
		_tmp53_ = serializable_property_int_test_int_node_new ();
#line 139 "SerializablePropertyIntTest.vala"
		i3 = _tmp53_;
#line 140 "SerializablePropertyIntTest.vala"
		_tmp54_ = i3;
#line 140 "SerializablePropertyIntTest.vala"
		_tmp55_ = doc3;
#line 140 "SerializablePropertyIntTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp54_, (GXmlNode*) _tmp55_, &_inner_error0_);
#line 140 "SerializablePropertyIntTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 140 "SerializablePropertyIntTest.vala"
			_g_object_unref0 (i3);
#line 140 "SerializablePropertyIntTest.vala"
			_g_object_unref0 (doc3);
#line 140 "SerializablePropertyIntTest.vala"
			_g_object_unref0 (i2);
#line 140 "SerializablePropertyIntTest.vala"
			_g_object_unref0 (doc2);
#line 140 "SerializablePropertyIntTest.vala"
			_g_object_unref0 (i1);
#line 140 "SerializablePropertyIntTest.vala"
			_g_object_unref0 (doc1);
#line 1397 "SerializablePropertyIntTest.c"
			goto __catch310_g_error;
		}
#line 141 "SerializablePropertyIntTest.vala"
		_tmp56_ = i3;
#line 141 "SerializablePropertyIntTest.vala"
		_tmp57_ = serializable_property_int_test_int_node_get_integer (_tmp56_);
#line 141 "SerializablePropertyIntTest.vala"
		_tmp58_ = _tmp57_;
#line 141 "SerializablePropertyIntTest.vala"
		_tmp59_ = gxml_serializable_property_get_serializable_property_value ((GXmlSerializableProperty*) _tmp58_);
#line 141 "SerializablePropertyIntTest.vala"
		_tmp60_ = _tmp59_;
#line 141 "SerializablePropertyIntTest.vala"
		_tmp61_ = g_strconcat ("Actual value: ", _tmp60_, NULL);
#line 141 "SerializablePropertyIntTest.vala"
		_tmp62_ = _tmp61_;
#line 141 "SerializablePropertyIntTest.vala"
		g_test_message ("%s", _tmp62_);
#line 141 "SerializablePropertyIntTest.vala"
		_g_free0 (_tmp62_);
#line 141 "SerializablePropertyIntTest.vala"
		_g_free0 (_tmp60_);
#line 142 "SerializablePropertyIntTest.vala"
		_tmp63_ = i3;
#line 142 "SerializablePropertyIntTest.vala"
		_tmp64_ = serializable_property_int_test_int_node_get_integer (_tmp63_);
#line 142 "SerializablePropertyIntTest.vala"
		_tmp65_ = _tmp64_;
#line 142 "SerializablePropertyIntTest.vala"
		_tmp66_ = gxml_serializable_property_get_serializable_property_value ((GXmlSerializableProperty*) _tmp65_);
#line 142 "SerializablePropertyIntTest.vala"
		_tmp67_ = _tmp66_;
#line 142 "SerializablePropertyIntTest.vala"
		_vala_assert (g_strcmp0 (_tmp67_, "1a") == 0, "i3.integer.get_serializable_property_value () == \"1a\"");
#line 142 "SerializablePropertyIntTest.vala"
		_g_free0 (_tmp67_);
#line 143 "SerializablePropertyIntTest.vala"
		_tmp68_ = i3;
#line 143 "SerializablePropertyIntTest.vala"
		_tmp69_ = serializable_property_int_test_int_node_get_integer (_tmp68_);
#line 143 "SerializablePropertyIntTest.vala"
		_tmp70_ = _tmp69_;
#line 143 "SerializablePropertyIntTest.vala"
		_tmp71_ = g_strdup_printf ("%i", gxml_serializable_int_get_value (_tmp70_));
#line 143 "SerializablePropertyIntTest.vala"
		_tmp72_ = _tmp71_;
#line 143 "SerializablePropertyIntTest.vala"
		_tmp73_ = g_strconcat ("Actual value parse: ", _tmp72_, NULL);
#line 143 "SerializablePropertyIntTest.vala"
		_tmp74_ = _tmp73_;
#line 143 "SerializablePropertyIntTest.vala"
		g_test_message ("%s", _tmp74_);
#line 143 "SerializablePropertyIntTest.vala"
		_g_free0 (_tmp74_);
#line 143 "SerializablePropertyIntTest.vala"
		_g_free0 (_tmp72_);
#line 144 "SerializablePropertyIntTest.vala"
		_tmp75_ = i3;
#line 144 "SerializablePropertyIntTest.vala"
		_tmp76_ = serializable_property_int_test_int_node_get_integer (_tmp75_);
#line 144 "SerializablePropertyIntTest.vala"
		_tmp77_ = _tmp76_;
#line 144 "SerializablePropertyIntTest.vala"
		_vala_assert (gxml_serializable_int_get_value (_tmp77_) == 1, "i3.integer.get_value () == 1");
#line 120 "SerializablePropertyIntTest.vala"
		_g_object_unref0 (i3);
#line 120 "SerializablePropertyIntTest.vala"
		_g_object_unref0 (doc3);
#line 120 "SerializablePropertyIntTest.vala"
		_g_object_unref0 (i2);
#line 120 "SerializablePropertyIntTest.vala"
		_g_object_unref0 (doc2);
#line 120 "SerializablePropertyIntTest.vala"
		_g_object_unref0 (i1);
#line 120 "SerializablePropertyIntTest.vala"
		_g_object_unref0 (doc1);
#line 1474 "SerializablePropertyIntTest.c"
	}
	goto __finally310;
	__catch310_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp78_;
		const gchar* _tmp79_;
		gchar* _tmp80_;
		gchar* _tmp81_;
#line 120 "SerializablePropertyIntTest.vala"
		e = _inner_error0_;
#line 120 "SerializablePropertyIntTest.vala"
		_inner_error0_ = NULL;
#line 146 "SerializablePropertyIntTest.vala"
		_tmp78_ = e->message;
#line 146 "SerializablePropertyIntTest.vala"
		_tmp79_ = string_to_string (_tmp78_);
#line 146 "SerializablePropertyIntTest.vala"
		_tmp80_ = g_strconcat ("ERROR: ", _tmp79_, NULL);
#line 146 "SerializablePropertyIntTest.vala"
		_tmp81_ = _tmp80_;
#line 146 "SerializablePropertyIntTest.vala"
		g_test_message ("%s", _tmp81_);
#line 146 "SerializablePropertyIntTest.vala"
		_g_free0 (_tmp81_);
#line 147 "SerializablePropertyIntTest.vala"
		g_assert_not_reached ();
#line 120 "SerializablePropertyIntTest.vala"
		_g_error_free0 (e);
#line 1504 "SerializablePropertyIntTest.c"
	}
	__finally310:
#line 120 "SerializablePropertyIntTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 120 "SerializablePropertyIntTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 120 "SerializablePropertyIntTest.vala"
		g_clear_error (&_inner_error0_);
#line 120 "SerializablePropertyIntTest.vala"
		return;
#line 1515 "SerializablePropertyIntTest.c"
	}
}

static void
___lambda255__gtest_func (void)
{
#line 118 "SerializablePropertyIntTest.vala"
	__lambda255_ ();
#line 1524 "SerializablePropertyIntTest.c"
}

void
serializable_property_int_test_add_tests (void)
{
#line 38 "SerializablePropertyIntTest.vala"
	g_test_add_func ("/gxml/serializable/Int/basic", ___lambda252__gtest_func);
#line 55 "SerializablePropertyIntTest.vala"
	g_test_add_func ("/gxml/serializable/Int/changes", ___lambda253__gtest_func);
#line 100 "SerializablePropertyIntTest.vala"
	g_test_add_func ("/gxml/serializable/Int/deserialize/basic", ___lambda254__gtest_func);
#line 118 "SerializablePropertyIntTest.vala"
	g_test_add_func ("/gxml/serializable/Int/deserialize/bad-value", ___lambda255__gtest_func);
#line 1538 "SerializablePropertyIntTest.c"
}

SerializablePropertyIntTest*
serializable_property_int_test_construct (GType object_type)
{
	SerializablePropertyIntTest* self = NULL;
#line 27 "SerializablePropertyIntTest.vala"
	self = (SerializablePropertyIntTest*) gxml_test_construct (object_type);
#line 27 "SerializablePropertyIntTest.vala"
	return self;
#line 1549 "SerializablePropertyIntTest.c"
}

SerializablePropertyIntTest*
serializable_property_int_test_new (void)
{
#line 27 "SerializablePropertyIntTest.vala"
	return serializable_property_int_test_construct (TYPE_SERIALIZABLE_PROPERTY_INT_TEST);
#line 1557 "SerializablePropertyIntTest.c"
}

static inline gpointer
serializable_property_int_test_int_node_get_instance_private (SerializablePropertyIntTestIntNode* self)
{
	return G_STRUCT_MEMBER_P (self, SerializablePropertyIntTestIntNode_private_offset);
}

static gchar*
serializable_property_int_test_int_node_real_node_name (GXmlSerializableObjectModel* base)
{
	SerializablePropertyIntTestIntNode * self;
	gchar* result = NULL;
	gchar* _tmp0_;
#line 33 "SerializablePropertyIntTest.vala"
	self = (SerializablePropertyIntTestIntNode*) base;
#line 33 "SerializablePropertyIntTest.vala"
	_tmp0_ = g_strdup ("IntNode");
#line 33 "SerializablePropertyIntTest.vala"
	result = _tmp0_;
#line 33 "SerializablePropertyIntTest.vala"
	return result;
#line 1580 "SerializablePropertyIntTest.c"
}

static gchar*
serializable_property_int_test_int_node_real_to_string (GXmlSerializableObjectModel* base)
{
	SerializablePropertyIntTestIntNode * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 34 "SerializablePropertyIntTest.vala"
	self = (SerializablePropertyIntTestIntNode*) base;
#line 34 "SerializablePropertyIntTest.vala"
	_tmp0_ = g_type_name (G_TYPE_FROM_INSTANCE ((GObject*) self));
#line 34 "SerializablePropertyIntTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 34 "SerializablePropertyIntTest.vala"
	result = _tmp1_;
#line 34 "SerializablePropertyIntTest.vala"
	return result;
#line 1600 "SerializablePropertyIntTest.c"
}

static gboolean
serializable_property_int_test_int_node_real_property_use_nick (GXmlSerializableObjectModel* base)
{
	SerializablePropertyIntTestIntNode * self;
	gboolean result = FALSE;
#line 35 "SerializablePropertyIntTest.vala"
	self = (SerializablePropertyIntTestIntNode*) base;
#line 35 "SerializablePropertyIntTest.vala"
	result = TRUE;
#line 35 "SerializablePropertyIntTest.vala"
	return result;
#line 1614 "SerializablePropertyIntTest.c"
}

SerializablePropertyIntTestIntNode*
serializable_property_int_test_int_node_construct (GType object_type)
{
	SerializablePropertyIntTestIntNode * self = NULL;
#line 28 "SerializablePropertyIntTest.vala"
	self = (SerializablePropertyIntTestIntNode*) gxml_serializable_object_model_construct (object_type);
#line 28 "SerializablePropertyIntTest.vala"
	return self;
#line 1625 "SerializablePropertyIntTest.c"
}

SerializablePropertyIntTestIntNode*
serializable_property_int_test_int_node_new (void)
{
#line 28 "SerializablePropertyIntTest.vala"
	return serializable_property_int_test_int_node_construct (SERIALIZABLE_PROPERTY_INT_TEST_TYPE_INT_NODE);
#line 1633 "SerializablePropertyIntTest.c"
}

GXmlSerializableInt*
serializable_property_int_test_int_node_get_integer (SerializablePropertyIntTestIntNode* self)
{
	GXmlSerializableInt* result;
	GXmlSerializableInt* _tmp0_;
#line 31 "SerializablePropertyIntTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 31 "SerializablePropertyIntTest.vala"
	_tmp0_ = self->priv->_integer;
#line 31 "SerializablePropertyIntTest.vala"
	result = _tmp0_;
#line 31 "SerializablePropertyIntTest.vala"
	return result;
#line 1649 "SerializablePropertyIntTest.c"
}

static gpointer
_g_object_ref0 (gpointer self)
{
#line 31 "SerializablePropertyIntTest.vala"
	return self ? g_object_ref (self) : NULL;
#line 1657 "SerializablePropertyIntTest.c"
}

void
serializable_property_int_test_int_node_set_integer (SerializablePropertyIntTestIntNode* self,
                                                     GXmlSerializableInt* value)
{
#line 31 "SerializablePropertyIntTest.vala"
	g_return_if_fail (self != NULL);
#line 31 "SerializablePropertyIntTest.vala"
	if (serializable_property_int_test_int_node_get_integer (self) != value) {
#line 1668 "SerializablePropertyIntTest.c"
		GXmlSerializableInt* _tmp0_;
#line 31 "SerializablePropertyIntTest.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 31 "SerializablePropertyIntTest.vala"
		_g_object_unref0 (self->priv->_integer);
#line 31 "SerializablePropertyIntTest.vala"
		self->priv->_integer = _tmp0_;
#line 31 "SerializablePropertyIntTest.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_property_int_test_int_node_properties[SERIALIZABLE_PROPERTY_INT_TEST_INT_NODE_INTEGER_PROPERTY]);
#line 1678 "SerializablePropertyIntTest.c"
	}
}

const gchar*
serializable_property_int_test_int_node_get_name (SerializablePropertyIntTestIntNode* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 32 "SerializablePropertyIntTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 32 "SerializablePropertyIntTest.vala"
	_tmp0_ = self->priv->_name;
#line 32 "SerializablePropertyIntTest.vala"
	result = _tmp0_;
#line 32 "SerializablePropertyIntTest.vala"
	return result;
#line 1695 "SerializablePropertyIntTest.c"
}

void
serializable_property_int_test_int_node_set_name (SerializablePropertyIntTestIntNode* self,
                                                  const gchar* value)
{
#line 32 "SerializablePropertyIntTest.vala"
	g_return_if_fail (self != NULL);
#line 32 "SerializablePropertyIntTest.vala"
	if (g_strcmp0 (value, serializable_property_int_test_int_node_get_name (self)) != 0) {
#line 1706 "SerializablePropertyIntTest.c"
		gchar* _tmp0_;
#line 32 "SerializablePropertyIntTest.vala"
		_tmp0_ = g_strdup (value);
#line 32 "SerializablePropertyIntTest.vala"
		_g_free0 (self->priv->_name);
#line 32 "SerializablePropertyIntTest.vala"
		self->priv->_name = _tmp0_;
#line 32 "SerializablePropertyIntTest.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_property_int_test_int_node_properties[SERIALIZABLE_PROPERTY_INT_TEST_INT_NODE_NAME_PROPERTY]);
#line 1716 "SerializablePropertyIntTest.c"
	}
}

static void
serializable_property_int_test_int_node_class_init (SerializablePropertyIntTestIntNodeClass * klass,
                                                    gpointer klass_data)
{
#line 28 "SerializablePropertyIntTest.vala"
	serializable_property_int_test_int_node_parent_class = g_type_class_peek_parent (klass);
#line 28 "SerializablePropertyIntTest.vala"
	g_type_class_adjust_private_offset (klass, &SerializablePropertyIntTestIntNode_private_offset);
#line 28 "SerializablePropertyIntTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->node_name = (gchar* (*) (GXmlSerializableObjectModel*)) serializable_property_int_test_int_node_real_node_name;
#line 28 "SerializablePropertyIntTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->to_string = (gchar* (*) (GXmlSerializableObjectModel*)) serializable_property_int_test_int_node_real_to_string;
#line 28 "SerializablePropertyIntTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->property_use_nick = (gboolean (*) (GXmlSerializableObjectModel*)) serializable_property_int_test_int_node_real_property_use_nick;
#line 28 "SerializablePropertyIntTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_serializable_property_int_test_int_node_get_property;
#line 28 "SerializablePropertyIntTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_serializable_property_int_test_int_node_set_property;
#line 28 "SerializablePropertyIntTest.vala"
	G_OBJECT_CLASS (klass)->finalize = serializable_property_int_test_int_node_finalize;
#line 28 "SerializablePropertyIntTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_PROPERTY_INT_TEST_INT_NODE_INTEGER_PROPERTY, serializable_property_int_test_int_node_properties[SERIALIZABLE_PROPERTY_INT_TEST_INT_NODE_INTEGER_PROPERTY] = g_param_spec_object ("integer", "IntegerValue", "integer", GXML_TYPE_SERIALIZABLE_INT, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 28 "SerializablePropertyIntTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_PROPERTY_INT_TEST_INT_NODE_NAME_PROPERTY, serializable_property_int_test_int_node_properties[SERIALIZABLE_PROPERTY_INT_TEST_INT_NODE_NAME_PROPERTY] = g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 1744 "SerializablePropertyIntTest.c"
}

static void
serializable_property_int_test_int_node_instance_init (SerializablePropertyIntTestIntNode * self,
                                                       gpointer klass)
{
#line 28 "SerializablePropertyIntTest.vala"
	self->priv = serializable_property_int_test_int_node_get_instance_private (self);
#line 1753 "SerializablePropertyIntTest.c"
}

static void
serializable_property_int_test_int_node_finalize (GObject * obj)
{
	SerializablePropertyIntTestIntNode * self;
#line 28 "SerializablePropertyIntTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SERIALIZABLE_PROPERTY_INT_TEST_TYPE_INT_NODE, SerializablePropertyIntTestIntNode);
#line 31 "SerializablePropertyIntTest.vala"
	_g_object_unref0 (self->priv->_integer);
#line 32 "SerializablePropertyIntTest.vala"
	_g_free0 (self->priv->_name);
#line 28 "SerializablePropertyIntTest.vala"
	G_OBJECT_CLASS (serializable_property_int_test_int_node_parent_class)->finalize (obj);
#line 1768 "SerializablePropertyIntTest.c"
}

GType
serializable_property_int_test_int_node_get_type (void)
{
	static volatile gsize serializable_property_int_test_int_node_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_property_int_test_int_node_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializablePropertyIntTestIntNodeClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_property_int_test_int_node_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializablePropertyIntTestIntNode), 0, (GInstanceInitFunc) serializable_property_int_test_int_node_instance_init, NULL };
		GType serializable_property_int_test_int_node_type_id;
		serializable_property_int_test_int_node_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_OBJECT_MODEL, "SerializablePropertyIntTestIntNode", &g_define_type_info, 0);
		SerializablePropertyIntTestIntNode_private_offset = g_type_add_instance_private (serializable_property_int_test_int_node_type_id, sizeof (SerializablePropertyIntTestIntNodePrivate));
		g_once_init_leave (&serializable_property_int_test_int_node_type_id__volatile, serializable_property_int_test_int_node_type_id);
	}
	return serializable_property_int_test_int_node_type_id__volatile;
}

static void
_vala_serializable_property_int_test_int_node_get_property (GObject * object,
                                                            guint property_id,
                                                            GValue * value,
                                                            GParamSpec * pspec)
{
	SerializablePropertyIntTestIntNode * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_PROPERTY_INT_TEST_TYPE_INT_NODE, SerializablePropertyIntTestIntNode);
#line 28 "SerializablePropertyIntTest.vala"
	switch (property_id) {
#line 28 "SerializablePropertyIntTest.vala"
		case SERIALIZABLE_PROPERTY_INT_TEST_INT_NODE_INTEGER_PROPERTY:
#line 28 "SerializablePropertyIntTest.vala"
		g_value_set_object (value, serializable_property_int_test_int_node_get_integer (self));
#line 28 "SerializablePropertyIntTest.vala"
		break;
#line 28 "SerializablePropertyIntTest.vala"
		case SERIALIZABLE_PROPERTY_INT_TEST_INT_NODE_NAME_PROPERTY:
#line 28 "SerializablePropertyIntTest.vala"
		g_value_set_string (value, serializable_property_int_test_int_node_get_name (self));
#line 28 "SerializablePropertyIntTest.vala"
		break;
#line 1807 "SerializablePropertyIntTest.c"
		default:
#line 28 "SerializablePropertyIntTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 28 "SerializablePropertyIntTest.vala"
		break;
#line 1813 "SerializablePropertyIntTest.c"
	}
}

static void
_vala_serializable_property_int_test_int_node_set_property (GObject * object,
                                                            guint property_id,
                                                            const GValue * value,
                                                            GParamSpec * pspec)
{
	SerializablePropertyIntTestIntNode * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_PROPERTY_INT_TEST_TYPE_INT_NODE, SerializablePropertyIntTestIntNode);
#line 28 "SerializablePropertyIntTest.vala"
	switch (property_id) {
#line 28 "SerializablePropertyIntTest.vala"
		case SERIALIZABLE_PROPERTY_INT_TEST_INT_NODE_INTEGER_PROPERTY:
#line 28 "SerializablePropertyIntTest.vala"
		serializable_property_int_test_int_node_set_integer (self, g_value_get_object (value));
#line 28 "SerializablePropertyIntTest.vala"
		break;
#line 28 "SerializablePropertyIntTest.vala"
		case SERIALIZABLE_PROPERTY_INT_TEST_INT_NODE_NAME_PROPERTY:
#line 28 "SerializablePropertyIntTest.vala"
		serializable_property_int_test_int_node_set_name (self, g_value_get_string (value));
#line 28 "SerializablePropertyIntTest.vala"
		break;
#line 1839 "SerializablePropertyIntTest.c"
		default:
#line 28 "SerializablePropertyIntTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 28 "SerializablePropertyIntTest.vala"
		break;
#line 1845 "SerializablePropertyIntTest.c"
	}
}

static void
serializable_property_int_test_class_init (SerializablePropertyIntTestClass * klass,
                                           gpointer klass_data)
{
#line 27 "SerializablePropertyIntTest.vala"
	serializable_property_int_test_parent_class = g_type_class_peek_parent (klass);
#line 1855 "SerializablePropertyIntTest.c"
}

static void
serializable_property_int_test_instance_init (SerializablePropertyIntTest * self,
                                              gpointer klass)
{
}

/**
 *
 *  SerializablePropertyIntTest.vala
 *
 *  Authors:
 *
 *       Daniel Espinosa <esodan@gmail.com>
 *
 *
 *  Copyright (c) 2015 Daniel Espinosa
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
GType
serializable_property_int_test_get_type (void)
{
	static volatile gsize serializable_property_int_test_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_property_int_test_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializablePropertyIntTestClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_property_int_test_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializablePropertyIntTest), 0, (GInstanceInitFunc) serializable_property_int_test_instance_init, NULL };
		GType serializable_property_int_test_type_id;
		serializable_property_int_test_type_id = g_type_register_static (TYPE_GXML_TEST, "SerializablePropertyIntTest", &g_define_type_info, 0);
		g_once_init_leave (&serializable_property_int_test_type_id__volatile, serializable_property_int_test_type_id);
	}
	return serializable_property_int_test_type_id__volatile;
}

